#!/usr/bin/env python

'''
usage:   nr-pdf-rotate.py my.pdf rotation result.pdf

        Rotation must be multiple of 90 degrees, clockwise.

Creates result.pdf with all rotated.

'''

import sys
import os

# import find_pdfrw
from pdfrw import PdfReader, PdfWriter

inpfn = sys.argv[1]
rotate = sys.argv[2]
outfn = sys.argv[3]

rotate = int(rotate)
assert rotate % 90 == 0

# ranges = [[int(y) for y in x.split('-')] for x in ranges]
trailer = PdfReader(inpfn)
pages = trailer.pages

ranges = [[1, len(pages)]]

for onerange in ranges:
    onerange = (onerange + onerange[-1:])[:2]
    for pagenum in range(onerange[0]-1, onerange[1]):
        pages[pagenum].Rotate = (int(pages[pagenum].inheritable.Rotate or 0) + rotate) % 360

outdata = PdfWriter()
outdata.trailer = trailer
outdata.write(outfn)




from distutils.core import setup

setup(
  name = 'pdfrw_rotate',
  packages = ['pdfrw_rotate'], # this must be the same as the name above
  version = '0.1.2',
  description = 'Executable to rotate all pages in a PDF document',
  long_description = 'This script uses the pdfrw library to perform a specified rotation on each page of the PDF docment.',
  author = 'Naive Roboticist',
  author_email = 'naiveroboticist@gmail.com',
  license = 'MIT',
  url = 'https://github.com/naiveroboticist/pdfrw_rotate',
  download_url = 'https://github.com/naiveroboticist/pdfrw_rotate/archive/0.1.tar.gz',
  keywords = ['pdfrw', 'rotate', 'pdf'],
  scripts=['bin/pdfrw_rotate.py'],
  classifiers = [],
)
